#[non_exhaustive]pub struct UserAgentEmulateHttpConnectModifierLayer;Trait Implementations
Sourceimpl Clone for UserAgentEmulateHttpConnectModifierLayer
impl Clone for UserAgentEmulateHttpConnectModifierLayer
Sourcefn clone(&self) -> UserAgentEmulateHttpConnectModifierLayer
fn clone(&self) -> UserAgentEmulateHttpConnectModifierLayer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UserAgentEmulateHttpConnectModifierLayer
impl Default for UserAgentEmulateHttpConnectModifierLayer
Sourcefn default() -> UserAgentEmulateHttpConnectModifierLayer
fn default() -> UserAgentEmulateHttpConnectModifierLayer
Returns the “default value” for a type. Read more
Sourceimpl<S> Layer<S> for UserAgentEmulateHttpConnectModifierLayer
impl<S> Layer<S> for UserAgentEmulateHttpConnectModifierLayer
Sourcetype Service = UserAgentEmulateHttpConnectModifier<S>
type Service = UserAgentEmulateHttpConnectModifier<S>
The service produced by the layer.
Sourcefn layer(&self, inner: S) -> Self::Service
fn layer(&self, inner: S) -> Self::Service
Wrap the given service with the middleware, returning a new service.
Sourcefn into_layer(self, inner: S) -> Self::Service
fn into_layer(self, inner: S) -> Self::Service
Same as
layer but consuming self after the service was created. Read moreAuto Trait Implementations
impl Freeze for UserAgentEmulateHttpConnectModifierLayer
impl RefUnwindSafe for UserAgentEmulateHttpConnectModifierLayer
impl Send for UserAgentEmulateHttpConnectModifierLayer
impl Sync for UserAgentEmulateHttpConnectModifierLayer
impl Unpin for UserAgentEmulateHttpConnectModifierLayer
impl UnsafeUnpin for UserAgentEmulateHttpConnectModifierLayer
impl UnwindSafe for UserAgentEmulateHttpConnectModifierLayer