UserAgentEmulateLayer

Struct UserAgentEmulateLayer 

pub struct UserAgentEmulateLayer<P> { /* private fields */ }
A layer that emulates a user agent profile.

See UserAgentEmulateService for more details.

This layer is used to emulate a user agent profile for a request. It makes use of a UserAgentProvider (P) to select a user agent profile.

Implementations

Source

impl<P> UserAgentEmulateLayer<P>

pub fn new(provider: P) -> Self

Create a new UserAgentEmulateLayer with the given provider.

pub fn with_is_optional(self, optional: bool) -> Self

When no user agent profile was found it will fail the request unless optional is true. In case of the latter the service will do nothing.

pub fn set_is_optional(&mut self, optional: bool) -> &mut Self

When no user agent profile was found it will fail the request unless optional is true. In case of the latter the service will do nothing.

pub fn with_try_auto_detect_user_agent( self, try_auto_detect_user_agent: bool, ) -> Self

If true, the layer will try to auto-detect the user agent from the request, but only in case that info is not yet found in the context.

pub fn set_try_auto_detect_user_agent( &mut self, try_auto_detect_user_agent: bool, ) -> &mut Self

If true, the layer will try to auto-detect the user agent from the request, but only in case that info is not yet found in the context.

pub fn maybe_with_input_header_order(self, name: Option<HeaderName>) -> Self

Define a header that if present is to contain a CSV header name list, that allows you to define the desired header order for the (extra) headers found in the input (http) request.

Extra meaning any headers not considered a base header and already defined by the (selected) User Agent Profile.

This can be useful because your http client might not respect the header casing and/or order of the headers taken together. Using this metadata allows you to communicate this data through anyway. If however your http client does respect casing and order, or you don’t care about some of it, you might not need it.

pub fn maybe_set_input_header_order( &mut self, name: Option<HeaderName>, ) -> &mut Self

Define a header that if present is to contain a CSV header name list, that allows you to define the desired header order for the (extra) headers found in the input (http) request.

Extra meaning any headers not considered a base header and already defined by the (selected) User Agent Profile.

This can be useful because your http client might not respect the header casing and/or order of the headers taken together. Using this metadata allows you to communicate this data through anyway. If however your http client does respect casing and order, or you don’t care about some of it, you might not need it.

pub fn with_input_header_order(self, name: HeaderName) -> Self

Define a header that if present is to contain a CSV header name list, that allows you to define the desired header order for the (extra) headers found in the input (http) request.

Extra meaning any headers not considered a base header and already defined by the (selected) User Agent Profile.

This can be useful because your http client might not respect the header casing and/or order of the headers taken together. Using this metadata allows you to communicate this data through anyway. If however your http client does respect casing and order, or you don’t care about some of it, you might not need it.

pub fn set_input_header_order(&mut self, name: HeaderName) -> &mut Self

Define a header that if present is to contain a CSV header name list, that allows you to define the desired header order for the (extra) headers found in the input (http) request.

Extra meaning any headers not considered a base header and already defined by the (selected) User Agent Profile.

This can be useful because your http client might not respect the header casing and/or order of the headers taken together. Using this metadata allows you to communicate this data through anyway. If however your http client does respect casing and order, or you don’t care about some of it, you might not need it.

pub fn without_input_header_order(self) -> Self

Define a header that if present is to contain a CSV header name list, that allows you to define the desired header order for the (extra) headers found in the input (http) request.

Extra meaning any headers not considered a base header and already defined by the (selected) User Agent Profile.

This can be useful because your http client might not respect the header casing and/or order of the headers taken together. Using this metadata allows you to communicate this data through anyway. If however your http client does respect casing and order, or you don’t care about some of it, you might not need it.

pub fn unset_input_header_order(&mut self) -> &mut Self

Define a header that if present is to contain a CSV header name list, that allows you to define the desired header order for the (extra) headers found in the input (http) request.

Extra meaning any headers not considered a base header and already defined by the (selected) User Agent Profile.

This can be useful because your http client might not respect the header casing and/or order of the headers taken together. Using this metadata allows you to communicate this data through anyway. If however your http client does respect casing and order, or you don’t care about some of it, you might not need it.

pub fn maybe_with_select_fallback( self, fb: Option<UserAgentSelectFallback>, ) -> Self

Choose what to do in case no profile could be selected using the regular pre-conditions as specified by the provider.

pub fn maybe_set_select_fallback( &mut self, fb: Option<UserAgentSelectFallback>, ) -> &mut Self

Choose what to do in case no profile could be selected using the regular pre-conditions as specified by the provider.

pub fn with_select_fallback(self, fb: UserAgentSelectFallback) -> Self

Choose what to do in case no profile could be selected using the regular pre-conditions as specified by the provider.

pub fn set_select_fallback(&mut self, fb: UserAgentSelectFallback) -> &mut Self

Choose what to do in case no profile could be selected using the regular pre-conditions as specified by the provider.

pub fn without_select_fallback(self) -> Self

Choose what to do in case no profile could be selected using the regular pre-conditions as specified by the provider.

pub fn unset_select_fallback(&mut self) -> &mut Self

Choose what to do in case no profile could be selected using the regular pre-conditions as specified by the provider.