UserAgentSelectFallback

Enum UserAgentSelectFallback 

pub enum UserAgentSelectFallback {
    Abort,
    Random,
}
Fallback strategy that can be injected into the context to customise what a provider can be requested to do in case the preconditions for UA selection were not fulfilled.

It is advised only fallback for pre-conditions and not post-selection failure as the latter would be rather confusing.

For example if you request a Chromium profile you do not expect a Firefox one. However if you do not give any filters it is fair to assume a random profile is desired, given those all satisfy the abscence of filters.

Variants



Abort

Abort the request if no profile is found.



Random

Select a random profile if no profile is found.