pub struct UserAgentEmulateService<S, P> { /* private fields */ }Expand description
Service to select a UserAgentProfile and inject its info into the input Extensions.
Note that actual http emulation is done by also ensuring a service
such as UserAgentEmulateHttpRequestModifier and UserAgentEmulateHttpConnectModifier is in use within your connector stack.
Tls emulation is facilitated by a tls client connector which respects
the injected (tls) client profile.
See the implementation ofEasyHttpWebClient for the reference implementation of how
one can make use of this profile to emulate a user agent on the tls layer.
Implementations
Sourceimpl<S, P> UserAgentEmulateService<S, P>
impl<S, P> UserAgentEmulateService<S, P>
Sourcepub fn new(inner: S, provider: P) -> Self
pub fn new(inner: S, provider: P) -> Self
Create a new UserAgentEmulateService with the given inner service and provider.
Provider is implicitly expected to be a UserAgentProvider.
Sourcepub fn with_is_optional(self, optional: bool) -> Self
pub fn with_is_optional(self, optional: bool) -> Self
When no user agent profile was found it will fail the request unless optional is true. In case of the latter the service will do nothing.
Sourcepub fn set_is_optional(&mut self, optional: bool) -> &mut Self
pub fn set_is_optional(&mut self, optional: bool) -> &mut Self
When no user agent profile was found it will fail the request unless optional is true. In case of the latter the service will do nothing.
Sourcepub fn with_try_auto_detect_user_agent(
self,
try_auto_detect_user_agent: bool,
) -> Self
pub fn with_try_auto_detect_user_agent( self, try_auto_detect_user_agent: bool, ) -> Self
If true, the service will try to auto-detect the user agent from the request, but only in case that info is not yet found in the context.
Sourcepub fn set_try_auto_detect_user_agent(
&mut self,
try_auto_detect_user_agent: bool,
) -> &mut Self
pub fn set_try_auto_detect_user_agent( &mut self, try_auto_detect_user_agent: bool, ) -> &mut Self
If true, the service will try to auto-detect the user agent from the request, but only in case that info is not yet found in the context.
Sourcepub fn maybe_with_input_header_order(self, name: Option<HeaderName>) -> Self
pub fn maybe_with_input_header_order(self, name: Option<HeaderName>) -> Self
Define a header that if present is to contain a CSV header name list, that allows you to define the desired header order for the (extra) headers found in the input (http) request.
Extra meaning any headers not considered a base header and already defined by the (selected) User Agent Profile.
This can be useful because your http client might not respect the header casing and/or order of the headers taken together. Using this metadata allows you to communicate this data through anyway. If however your http client does respect casing and order, or you don’t care about some of it, you might not need it.
Sourcepub fn maybe_set_input_header_order(
&mut self,
name: Option<HeaderName>,
) -> &mut Self
pub fn maybe_set_input_header_order( &mut self, name: Option<HeaderName>, ) -> &mut Self
Define a header that if present is to contain a CSV header name list, that allows you to define the desired header order for the (extra) headers found in the input (http) request.
Extra meaning any headers not considered a base header and already defined by the (selected) User Agent Profile.
This can be useful because your http client might not respect the header casing and/or order of the headers taken together. Using this metadata allows you to communicate this data through anyway. If however your http client does respect casing and order, or you don’t care about some of it, you might not need it.
Sourcepub fn with_input_header_order(self, name: HeaderName) -> Self
pub fn with_input_header_order(self, name: HeaderName) -> Self
Define a header that if present is to contain a CSV header name list, that allows you to define the desired header order for the (extra) headers found in the input (http) request.
Extra meaning any headers not considered a base header and already defined by the (selected) User Agent Profile.
This can be useful because your http client might not respect the header casing and/or order of the headers taken together. Using this metadata allows you to communicate this data through anyway. If however your http client does respect casing and order, or you don’t care about some of it, you might not need it.
Sourcepub fn set_input_header_order(&mut self, name: HeaderName) -> &mut Self
pub fn set_input_header_order(&mut self, name: HeaderName) -> &mut Self
Define a header that if present is to contain a CSV header name list, that allows you to define the desired header order for the (extra) headers found in the input (http) request.
Extra meaning any headers not considered a base header and already defined by the (selected) User Agent Profile.
This can be useful because your http client might not respect the header casing and/or order of the headers taken together. Using this metadata allows you to communicate this data through anyway. If however your http client does respect casing and order, or you don’t care about some of it, you might not need it.
Sourcepub fn without_input_header_order(self) -> Self
pub fn without_input_header_order(self) -> Self
Define a header that if present is to contain a CSV header name list, that allows you to define the desired header order for the (extra) headers found in the input (http) request.
Extra meaning any headers not considered a base header and already defined by the (selected) User Agent Profile.
This can be useful because your http client might not respect the header casing and/or order of the headers taken together. Using this metadata allows you to communicate this data through anyway. If however your http client does respect casing and order, or you don’t care about some of it, you might not need it.
Sourcepub fn unset_input_header_order(&mut self) -> &mut Self
pub fn unset_input_header_order(&mut self) -> &mut Self
Define a header that if present is to contain a CSV header name list, that allows you to define the desired header order for the (extra) headers found in the input (http) request.
Extra meaning any headers not considered a base header and already defined by the (selected) User Agent Profile.
This can be useful because your http client might not respect the header casing and/or order of the headers taken together. Using this metadata allows you to communicate this data through anyway. If however your http client does respect casing and order, or you don’t care about some of it, you might not need it.
Sourcepub fn maybe_with_select_fallback(
self,
fb: Option<UserAgentSelectFallback>,
) -> Self
pub fn maybe_with_select_fallback( self, fb: Option<UserAgentSelectFallback>, ) -> Self
Choose what to do in case no profile could be selected using the regular pre-conditions as specified by the provider.
Sourcepub fn maybe_set_select_fallback(
&mut self,
fb: Option<UserAgentSelectFallback>,
) -> &mut Self
pub fn maybe_set_select_fallback( &mut self, fb: Option<UserAgentSelectFallback>, ) -> &mut Self
Choose what to do in case no profile could be selected using the regular pre-conditions as specified by the provider.
Sourcepub fn with_select_fallback(self, fb: UserAgentSelectFallback) -> Self
pub fn with_select_fallback(self, fb: UserAgentSelectFallback) -> Self
Choose what to do in case no profile could be selected using the regular pre-conditions as specified by the provider.
Sourcepub fn set_select_fallback(&mut self, fb: UserAgentSelectFallback) -> &mut Self
pub fn set_select_fallback(&mut self, fb: UserAgentSelectFallback) -> &mut Self
Choose what to do in case no profile could be selected using the regular pre-conditions as specified by the provider.
Sourcepub fn without_select_fallback(self) -> Self
pub fn without_select_fallback(self) -> Self
Choose what to do in case no profile could be selected using the regular pre-conditions as specified by the provider.
Sourcepub fn unset_select_fallback(&mut self) -> &mut Self
pub fn unset_select_fallback(&mut self) -> &mut Self
Choose what to do in case no profile could be selected using the regular pre-conditions as specified by the provider.